@@ -17,6 +17,9 @@ from threading import Thread
 
 
 
+
+
+
 def decode_line(encoded):
 
     """Decodes a polyline that was encoded using the Google Maps method.
@@ -136,6 +139,71 @@ class googleRoutesearchDownloader(Thread):
             sll = [ sl.getElementsByTagName("lat")[0].childNodes[0].data, sl.getElementsByTagName("lng")[0].childNodes[0].data]
             ell = [ el.getElementsByTagName("lat")[0].childNodes[0].data, el.getElementsByTagName("lng")[0].childNodes[0].data]
 
+
+
+            # ---------------------------------- PARSE STREET NAMES
+            str_no_street_name = step.getElementsByTagName("html_instructions")[0].childNodes[0].data
+            print "----------------------------------------\nno street_name A:\t\t[",str_no_street_name,"]"
+
+            m = re.search(r'(.*) <b>(.*)</b>(.*)<b>(.*)</b>(.*)<b>(.*)</b>', str_no_street_name, re.M|re.I)
+            try:
+                m.group(0)
+                str_no_street_name = "%s %s"%(m.group(1), m.group(2))
+                print "m"
+            except:
+                pass
+
+            m0 = re.search(r'<b>(.*)</b>(.*)<b>(.*)</b>(.*)<b>(.*)</b>', str_no_street_name, re.M|re.I)
+            try:
+                m0.group(0)
+                m0.group(1)
+                str_no_street_name = "%s %s"%(m0.group(2), m0.group(3))
+                print "0"
+            except:
+                pass
+
+            m2 = re.search(r'(.*) <b>(.*)</b> (.*) <b>(.*)</b><div style="font-size:0.9em">(.*)</div>', str_no_street_name, re.M|re.I)
+            try:
+                m2.group(0)
+                str_no_street_name = "%s %s %s"%(m2.group(1), m2.group(2),m2.group(5))
+                print "2"
+            except:
+                pass
+
+            m1 = re.search(r'(.*)<b>(.*)</b>(.*)<b>(.*)</b>', str_no_street_name, re.M|re.I)
+            try:
+                m1.group(0)
+                str_no_street_name = "%s %s"%(m1.group(1), m1.group(2))
+                print "1"
+            except:
+                pass
+
+
+            m33 = re.search(r'(.*) <b>(.*)</b><div style="font-size:0.9em">(.*)</div>', str_no_street_name, re.M|re.I)
+            try:
+                m33.group(0)
+                str_no_street_name = "%s. %s"%(m33.group(1), m33.group(3))
+                print "33"
+            except:
+                pass
+
+
+            m3 = re.search(r'(.*) <b>(.*)</b>', str_no_street_name, re.M|re.I)
+            try:
+                m3.group(0)
+                str_no_street_name = "%s"%(m3.group(1))
+                print "3"
+            except:
+                pass
+
+
+
+
+
+            print "no street_name B:\t\t[",str_no_street_name,"]"
+
+
+
             str = re.sub(r'<[^>]*?>', ' ', step.getElementsByTagName("html_instructions")[0].childNodes[0].data )
             str = str.replace("  ", " ")
             ico = None
@@ -170,7 +238,8 @@ class googleRoutesearchDownloader(Thread):
                                      float(sll[0]),float(sll[1]),
                                      str,
                                      ico,
-                                     ico_name
+                                     ico_name,
+                                     str_no_street_name
                                      ])
                 t = osmgpsmap.GpsMapTrack()
                 t.props.color = gtk.gdk.color_parse("#1a39fb")
@@ -211,7 +280,8 @@ class googleRoutesearchDownloader(Thread):
                                      m[0],m[1],
                                      str,
                                      m[3],
-                                     m[4]
+                                     m[4],
+                                     str_no_street_name
                                     ])
 
 
@@ -315,6 +385,13 @@ class google_routesearch:
         self.CONFIG = CONFIG
         self.osmMapa = osmMapa
 
+
+        self.ico = "route.png"
+        self.ui_menu_main = 0
+        self.ui_menu_left = 1
+        self.ui_search = 0
+
+
         self.tp = ""
         self.timeout = 5
         self.draw = 0
@@ -341,8 +418,8 @@ class google_routesearch:
         self.espeak_dis = 0
         self.espeak_time = 0
         self.espeak_langs = []
-        
-        
+
+
         self.recalculate_in_progress = 0
 
         if os.path.isfile("/usr/bin/espeak"):
@@ -381,13 +458,19 @@ class google_routesearch:
             else:
                 self.CONFIG['google_routesearch_speak'] = 0
 
+        try:
+            print "google_routesearch speak streets nams:", self.CONFIG['google_routesearch_speak_streets_names']
+        except:
+            self.CONFIG['google_routesearch_speak_streets_names'] = 1
+
+
         #self.ico = "google_routesearch.png"
 
         try:
             print "google_routesearch auto recal:", self.CONFIG['google_routesearch_auto_recal']
         except:
             self.CONFIG['google_routesearch_auto_recal'] = 500
-        
+
         try:
             print "google_routesearch auto recal make:", self.CONFIG['google_routesearch_auto_recal_make']
         except:
@@ -402,7 +485,7 @@ class google_routesearch:
         except:
             self.CONFIG['google_routesearch_to'] = ""
 
-        
+
         try:
             print "google_routesearch mode:", self.CONFIG['google_routesearch_mode']
         except:
@@ -437,7 +520,11 @@ class google_routesearch:
         """
         cmd = "espeak -v %s \"%s\" &"%( self.CONFIG['google_routesearch_speak_street_lang'], str)
 
-        print "[[[%s]]]"%cmd
+
+
+
+
+        #print "[[[%s]]]"%cmd
         #return None
         os.system(cmd)
 
@@ -458,7 +545,7 @@ class google_routesearch:
         if d < 0:
             d = -d
         tr = d/( math.sqrt( (a*a)+(b*b) ) )
-        
+
         return tr
 
     def angle_from_vector(self, pa, pb, pc):
@@ -475,9 +562,15 @@ class google_routesearch:
             res = -res
         return res
 
+    def get_key_point_speak(self,m ):
+        if not self.CONFIG['google_routesearch_speak_streets_names']:
+            return m[5]
+        else:
+            return m[2]
+
     def do_draw(self, gpsmap, gdkdrawable):
         print "drive mode", self.drive_mode
-        
+
         if self.osmMapa.osm.props.zoom>self.zoom_minimum:
 
 
@@ -528,7 +621,7 @@ class google_routesearch:
                     angle = self.angle_from_vector( [p[0],p[1]], [latc,lonc],[p_old[0],p_old[1]] )
                     dis = self.osmMapa.distance( p[0],p[1], p_old[0],p_old[1] )
                     dis_total+=dis
-                    
+
                     if dis_min == -10:
                         dis_min = angle
                         id_next = i
@@ -554,21 +647,21 @@ class google_routesearch:
                 """
                 x,y = self.osmMapa.osm.geographic_to_screen(a[0],a[1])
                 self.osmMapa.draw_cloud( cr, x,y, ("a\n[%f,%f]"%(a[0],a[1])) )
-                
+
                 x,y = self.osmMapa.osm.geographic_to_screen(b[0],b[1])
                 self.osmMapa.draw_cloud( cr, x,y, ("b\n[%f,%f]"%(b[0],b[1])) )
-                
+
                 x,y = self.osmMapa.osm.geographic_to_screen(c[0],c[1])
                 self.osmMapa.draw_cloud( cr, x,y, ("c\n[%f,%f]"%(c[0],c[1])) )
                 """
-                
+
                 ll_ab = self.osmMapa.cal_dist( a[0],a[1],b[0],b[1])
                 km_ab = self.osmMapa.distance( a[0],a[1],b[0],b[1])
                 ll_cv = self.dist_from_vector(a,b,c)
-                
+
                 res_scale = ((ll_cv*km_ab)/ll_ab)*1000
-                
-                
+
+
                 print res_scale," max ",int(self.CONFIG['google_routesearch_auto_recal'])
                 if res_scale > 60:
                     self.osmMapa.draw_arrow(
@@ -576,13 +669,13 @@ class google_routesearch:
                                             self.points[id_next][0],
                                             self.points[id_next][1]
                                             )
-                
+
                 if res_scale > int(self.CONFIG['google_routesearch_auto_recal']) and self.recalculate_in_progress == 0 and self.drive_mode == 1:
                     self.recalculate_in_progress = 1
                     self.clean_layer()
                     self.CONFIG['google_routesearch_from'] = "my current location"
                     self.search_action()
-                    
+
 
 
             search_for_it = -1
@@ -646,7 +739,7 @@ class google_routesearch:
                             self.espeak_dis = 0.203
                             self.espeak_time = t+5
 
-                            speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  m[2])
+                            speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  self.get_key_point_speak(m))
                             if self.CONFIG['google_routesearch_speak']:
                                 self.espeak_cmd( speak )
                         elif self.espeak_say == m[2] and t > (self.espeak_time):
@@ -656,7 +749,7 @@ class google_routesearch:
                                     self.espeak_dis = dis_to_key
                                     self.espeak_time = t+4
 
-                                    speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  m[2])
+                                    speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  self.get_key_point_speak(m))
                                     if self.CONFIG['google_routesearch_speak']:
                                         self.espeak_cmd( speak )
 
@@ -664,14 +757,14 @@ class google_routesearch:
                                     self.espeak_dis = dis_to_key
                                     self.espeak_time = t+4
 
-                                    speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  m[2])
+                                    speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  self.get_key_point_speak(m))
                                     if self.CONFIG['google_routesearch_speak']:
                                         self.espeak_cmd( speak )
                                 elif dis_to_key < 0.025 and self.espeak_dis > 0:
                                     self.espeak_dis = dis_to_key
                                     self.espeak_time = t+30
 
-                                    speak = "%s" % ( m[2])
+                                    speak = "%s" % ( self.get_key_point_speak(m))
                                     if self.CONFIG['google_routesearch_speak']:
                                         self.espeak_cmd( speak )
 
@@ -701,7 +794,7 @@ class google_routesearch:
 
     def clean_layer(self):
         self.drive_mode = 0
-        
+
         for i in self.markers_icons:
             self.osmMapa.osm.image_remove( i )
         self.markers_icons = []
@@ -805,7 +898,7 @@ class google_routesearch:
                 break
 
         print "selected lang: ", self.CONFIG['google_routesearch_speak_street_lang']
-    
+
     def on_changed_dis (self,picker,dialog):
         str = picker.get_value()
         for i in range( 100, 1500, 100):
@@ -814,7 +907,7 @@ class google_routesearch:
                 break
 
         print "selected google_routesearch_auto_recal: ", self.CONFIG['google_routesearch_auto_recal']
-        
+
     def on_bt_relac(self,w):
         if w.get_active():
             self.CONFIG['google_routesearch_auto_recal_make'] = 1
@@ -852,24 +945,98 @@ class google_routesearch:
             f.close()
     def on_bt_speak(self, w):
         self.CONFIG['google_routesearch_speak'] = w.get_active()
+    def on_bt_speak_st(self, w):
+        self.CONFIG['google_routesearch_speak_streets_names'] = w.get_active()
 
     def get_menu_widgets(self, dialog):
+
+
         vbox = gtk.VBox()
 
+        mvbox = gtk.VBox()
+        panel = hildon.PannableArea()
+        panel.add_with_viewport(mvbox)
+        vbox.pack_start( panel, True,True)
+        panel.set_size_request(640, 280)
 
-        hbox =gtk.HBox()
-        hbox.pack_start(gtk.Label("A:"),False)
+
+        abox = gtk.HBox()
+        abox.pack_start(gtk.Label("A:"),False)
         self.e_start = gtk.Entry()
         self.e_start.set_text(self.CONFIG['google_routesearch_from'])
-        hbox.pack_start(self.e_start, True)
-        vbox.pack_start(hbox, True)
+        abox.pack_start(self.e_start, True)
 
-        hbox =gtk.HBox()
-        hbox.pack_start(gtk.Label("B:"),False)
+        bbox =gtk.HBox()
+        bbox.pack_start(gtk.Label("B:"),False)
         self.e_end = gtk.Entry()
         self.e_end.set_text(self.CONFIG['google_routesearch_to'])
-        hbox.pack_start(self.e_end, True)
-        vbox.pack_start(hbox, True)
+        bbox.pack_start(self.e_end, True)
+
+
+        abbox = gtk.VBox()
+        abbox.pack_start( abox,True)
+        abbox.pack_start( bbox,True)
+
+
+        scbox = gtk.HBox()
+        bt_swap = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL, "swap")
+        #bt_swap.set_text("swap points","some value")
+        bt_swap.connect("clicked", self.on_swap)
+        scbox.pack_start( bt_swap, False)
+
+        bt_c = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear")
+        bt_c.connect("clicked", self.on_clean)
+        scbox.pack_start( bt_c, False)
+
+
+
+
+        abscbox = gtk.HBox()
+        abscbox.pack_start( abbox, True )
+        abscbox.pack_start( scbox, False )
+        mvbox.pack_start( abscbox, True)
+
+
+
+
+
+
+
+        """
+        #sftp://yoyo@yoyo.ghost.pl/home/yoyo/yosmapa_builder/yosmapa_builder
+        self.bt_auto = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
+        self.bt_auto.set_label("auto")
+        hbox.pack_start(self.bt_offline, True)
+        mvbox.pack_start( hbox, True )
+        """
+
+        hbox = gtk.HBox()
+
+        bt_a = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
+        bt_a.connect("clicked", self.on_add)
+        hbox.pack_start( bt_a, True)
+
+
+        bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Find route")
+        bt_search.connect("clicked", self.on_search, dialog)
+        hbox.pack_start( bt_search, True)
+
+        if len( self.tracks ):
+            bt_clear = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear route")
+            bt_clear.connect("clicked", self.on_clear, dialog)
+            hbox.pack_start( bt_clear, True)
+
+
+        mvbox.pack_start(hbox, True)
+
+
+
+        mvbox.pack_start(gtk.HSeparator(),True)
 
 
         hbox = gtk.HBox()
@@ -889,64 +1056,14 @@ class google_routesearch:
         self.bt_offline = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
         self.bt_offline.set_label("work offline")
         hbox.pack_start(self.bt_offline, True)
-        vbox.pack_start( hbox, True )
+        mvbox.pack_start( hbox, True )
+
+        mvbox.pack_start(gtk.HSeparator(),True)
 
 
-        
-
-
-        """
-        #sftp://yoyo@yoyo.ghost.pl/home/yoyo/yosmapa_builder/yosmapa_builder
-        self.bt_auto = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
-        self.bt_auto.set_label("auto")
-        hbox.pack_start(self.bt_offline, True)
-        vbox.pack_start( hbox, True )
-        """
-
-        hbox = gtk.HBox()
-
-        bt_a = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
-        bt_a.connect("clicked", self.on_add)
-        hbox.pack_start( bt_a, True)
-
-
-        bt_c = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear")
-        bt_c.connect("clicked", self.on_clean)
-        hbox.pack_start( bt_c, True)
-
-
-        bt_swap = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL, "swap points")
-        #bt_swap.set_text("swap points","some value")
-        bt_swap.connect("clicked", self.on_swap)
-        hbox.pack_start( bt_swap, True)
-
-        bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Find")
-        bt_search.connect("clicked", self.on_search, dialog)
-        hbox.pack_start( bt_search, True)
-
-        if len( self.tracks ):
-            bt_clear = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"clear")
-            bt_clear.connect("clicked", self.on_clear, dialog)
-            hbox.pack_start( bt_clear, True)
-
-
-        vbox.pack_start(hbox, True)
-
-
-                
-        extra = gtk.Expander()
-        extra.set_label("Extras:")
-        ve = gtk.VBox()
-        extra.add(ve)
-        
         if self.espeak:
             l = gtk.Label("espeak settings:")
-            ve.pack_start(l,False)
+            mvbox.pack_start(l,False)
             hbox = gtk.HBox()
             self.bt_speak = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
             self.bt_speak.set_label("speak")
@@ -969,28 +1086,38 @@ class google_routesearch:
             pb_lang.set_active( id  )
             pb_lang.connect("value-changed",self.on_changed_lang, dialog)
             hbox.pack_start( pb_lang, True )
-            ve.pack_start(hbox,True)
-            ve.pack_start(gtk.HSeparator(),True)
-        
+            mvbox.pack_start(hbox,True)
+
+
+
+            self.bt_speak_st = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
+            self.bt_speak_st.set_label("speak\nstreet names")
+            if self.CONFIG['google_routesearch_speak_streets_names']:
+                self.bt_speak_st.set_active( True )
+            self.bt_speak_st.connect("clicked", self.on_bt_speak_st)
+            hbox.pack_start(self.bt_speak_st, True)
+
+            mvbox.pack_start(gtk.HSeparator(),True)
+
         if len( self.tracks ):
             bt_export = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Export route to gpx")
             bt_export.connect("clicked", self.on_bt_export, dialog )
-            ve.pack_start( bt_export, True)
-            ve.pack_start(gtk.HSeparator(),True)
-        
-        
+            mvbox.pack_start( bt_export, True)
+            mvbox.pack_start(gtk.HSeparator(),True)
+
+
         l = gtk.Label("auto recalculation:")
-        ve.pack_start(l,False)
+        mvbox.pack_start(l,False)
         hbox = gtk.HBox()
         #self.CONFIG['google_routesearch_auto_recal']
-        
+
         self.bt_recal = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
         self.bt_recal.set_label("make it")
         self.bt_recal.set_active( self.CONFIG['google_routesearch_auto_recal_make'] )
         self.bt_recal.connect("clicked", self.on_bt_relac )
         hbox.pack_start(self.bt_recal, True)
-                
+
         pb_dis = hildon.PickerButton(gtk.HILDON_SIZE_AUTO,
                                         hildon.BUTTON_ARRANGEMENT_VERTICAL)
         pb_dis.set_title("if distance is greater than [meters]")
@@ -1005,14 +1132,11 @@ class google_routesearch:
         pb_dis.set_active( id  )
         pb_dis.connect("value-changed",self.on_changed_dis, dialog)
         hbox.pack_start( pb_dis, True )
-        
-        
-        ve.pack_start(hbox,True)
-        ve.pack_start(gtk.HSeparator(),True)
-        
-        
-        
-        vbox.pack_start( extra, True)
+
+
+        mvbox.pack_start(hbox,True)
+        mvbox.pack_start(gtk.HSeparator(),True)
+
 
         return vbox
 
