@@ -52,6 +52,7 @@ import hildon
 import dbus.glib
 import cairo
 import time
+import md5
 
 gobject.threads_init()
 from dbus import glib
@@ -63,8 +64,13 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.19"
 """
+0.19-7
+    plugin[google_routesearch] as a stand alone plugin on left menu
+        speak or not speak street names :)
+        ui clean up
 0.19-6
     recent search button fix up
+    recent search icons back !
 0.19-5
     move from gtk.Button to hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,
@@ -256,8 +262,6 @@ maps_source = [
 
 
 
-
-
 try:
     from win32com.shell import shellcon, shell
     home = ("%s\\.%s_%s.conf" % (hell.SHGetFolderPath(0, shellcon.CSIDL_APPDATA, 0, 0), name,"0.18") )
@@ -344,7 +348,7 @@ class SearchDialog( hildon.Dialog):
         except:
             CONFIG['recent_search'] = []
 
-        recent_max = 30
+        recent_max = 100
         if len( CONFIG['recent_search'] ) > recent_max:
             CONFIG['recent_search'].pop(  )
 
@@ -361,10 +365,14 @@ class SearchDialog( hildon.Dialog):
 
             for s in CONFIG['recent_search']:
                 hbox = gtk.HBox()
-                #if s[0] <> "":
-                #    img = gtk.Image()
-                #    img.set_from_file(s[1])
-                #    hbox.pack_start(img,False)
+                try:
+                    f_name = "%s_%s.jpg" % (home, md5.new(s[0]).hexdigest())
+                    if os.path.isfile(f_name):
+                        img = gtk.Image()
+                        img.set_from_file(f_name)
+                        hbox.pack_start(img,False)
+                except:
+                    pass
                 b = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,s[0])
                 b.connect("clicked", self.on_recent_click)
@@ -452,7 +460,7 @@ class SearchDialog( hildon.Dialog):
         if e_search:
             CONFIG['search'] = e_search.get_text()
         reTmp = []
-        reTmp.append( [CONFIG['search']] )
+        reTmp.append( [CONFIG['search'],None] )
         for r in CONFIG['recent_search']:
             if r[0] <> CONFIG['search']:
                 reTmp.append( r )
@@ -504,29 +512,29 @@ class SearchDialog( hildon.Dialog):
 
     def make_delay_iter_for_ui_thread(self, plugin):
         print "make_delay_iter_for_ui_thread ",plugin[0].get_name()
-        
+
         self.threaded_plugin_loop.append( plugin[0] )
-        
+
         if len( self.threaded_plugin_loop ) == 1:
             self.make_threaded_plugin_loop_run()
-            
+
     def make_threaded_plugin_loop_run(self):
-        
-        
+
+
         working = 0
         for p in self.threaded_plugin_loop:
             if p.ui_thread == 1:
                 working+=1
-        
+
         if working == 0:
             self.threaded_plugin_loop = []
             self.osmMapa.recalculate_center_and_zoom()
-        
-        
+
+
         if len( self.threaded_plugin_loop ) > 0:
             print "make_threaded_plugin_loop_run loop",len( self.threaded_plugin_loop )
-            gobject.timeout_add( 1000, self.make_threaded_plugin_loop_run )        
-     
+            gobject.timeout_add( 1000, self.make_threaded_plugin_loop_run )
+
 
     def on_result_release(self, w, item):
         print "item release:",item
@@ -855,10 +863,10 @@ Autor: Bartlomiej Ceglik <yoyoek[noSpam]wp.pl>""")
 
                     break
         print "plugins killIt:",deactive_list
-        
+
         self.osmMapa.do_draw_plugins = []
         self.osmMapa.do_button_release_plugins = []
-                
+
         for a in deactive_list:
             for plugin in self.osmMapa.plugins_list:
                 pn = plugin[1]
@@ -1072,7 +1080,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                     mi = gtk.MenuItem("___________Center to")
                     mi.connect("activate",self.on_set_center,c[4],c[5])
                     m.append(mi)
-                    
+
                     if CONFIG['POI']:
                         mi = gtk.MenuItem("___________Add as POI")
                         mi.connect("activate",self.on_add_as_poi,c[4],c[5])
@@ -1202,10 +1210,10 @@ class UI(gtk.Window):
         self.ben_iter = 100
         self.show_find_results = []
         self.find_plugins = []
-        
+
         self.do_draw_plugins = []
         self.do_button_release_plugins = []
-        
+
 
         CONFIG['work_work_work'] = 1
 
@@ -1291,6 +1299,7 @@ class UI(gtk.Window):
 
     def recalculate_center_and_zoom(self):
         print "recalculate_center_and_zoom"
+        ico = None
         if len(self.show_find_results)>0:
             self.set_gpslock(0)
             if len(self.show_find_results ) == 1:
@@ -1300,6 +1309,11 @@ class UI(gtk.Window):
                 t_lt, t_ln, b_lt, b_ln = 0.0, 0.0, 0.0, 0.0
                 for i,p in enumerate(self.show_find_results):
                     p[6] = 0
+                    if not ico and p[4]:
+                        ico = p[4]
+                        f_name = "%s_%s.jpg" % (home, md5.new(CONFIG['search']).hexdigest() )
+                        ico.save( f_name, "png", {"quality":"100"}  )
+
                     if i == 0:
                         t_lt, t_ln, b_lt, b_ln = p[0],p[1],p[0],p[1]
 
@@ -1310,6 +1324,9 @@ class UI(gtk.Window):
 
                 print t_lt, t_ln, b_lt, b_ln
 
+
+
+
                 dis = self.distance( t_lt,t_ln, b_lt,b_ln )*1000
                 acc_scale = {
                       18: 70,
@@ -1339,6 +1356,9 @@ class UI(gtk.Window):
 
                 latc, lonc = [(t_lt+b_lt)/2,(t_ln+b_ln)/2]
                 self.osm.set_center_and_zoom(latc,lonc,zoom )
+
+
+
         print "recalculate_center_and_zoom ---- Done"
 
     def marker_draw(self,cr):
@@ -1859,8 +1879,8 @@ class PluginsLayer(gobject.GObject, osmgpsmap.GpsMapLayer):
                             self.osmMapa.do_draw_plugins.append(plugin)
                     except Exception, e:
                         print "PluginsLayer do_draw ERROR (",plugin[1],"):", e
-                        
-            
+
+
             if timing_plugins:
                 print "PluginsLayers in",(time.time()-t)
             self.make_draw = 0
